@@ -46,7 +46,6 @@
 #include "gsm-dbus.h"
 #include "gsm-sound.h"
 #include "gsm-gsd.h"
-#include "gsm-proxy.h"
 #include "gsm-keyring.h"
 #include "gsm-xrandr.h"
 #include "gsm-at-startup.h"
@@ -423,8 +422,6 @@ main (int argc, char *argv[])
 
   ignore (SIGPIPE);
 
-  gsm_set_up_legacy_proxy_environment ();
-
   /* Need DISPLAY set */
   gsm_keyring_daemon_start ();
   dbus_daemon_owner = gsm_dbus_daemon_start ();
@@ -489,6 +486,9 @@ main (int argc, char *argv[])
 
   start_session (the_session);
 
+  if (a_t_support) /* the ATs are happier if the session has started */
+    gsm_assistive_technologies_start ();
+
   gtk_main ();
 
   gsm_remote_desktop_cleanup ();
